Learn R Programming

seedwater (version 2.0)

onionseeds: Onion Seed Soaking Kinetics Data

Description

Data from a lab experiment containing observations of onion seed sample weight (g) subjected to a soaking process for 96 hours.

Usage

data("onionseeds")

Arguments

Format

A data frame with 23 observations on the following 2 variables:

Time

a numeric vector containing values of soaking time, in hours.

Weight

a numeric vector containing values of weight (g) of a onion seed sample.

Examples

Run this code
# NOT RUN {
data(onionseeds)
str(onionseeds)
summary(onionseeds)
plot(Weight ~ Time, data = onionseeds)
# }

Run the code above in your browser using DataLab