Learn R Programming

seedwater (version 2.0)

seedwater-package: Models for Drying and Soaking Kinetics of Seeds

Description

Bringing together tools for modeling drying and soaking (rehydration) kinetics of seeds. This package contains several widely used predictive models (e.g.: da Silva et al., 2018). As these are nonlinear, the functions are interactive-based and easy-to-use. Least squares estimates are obtained with just a few visual adjustments of the initial parameter values.

Arguments

Details

Package: seedwater
Type: Package
Version: 2.0
Date: 2020-12-04
License: GPL (>= 2)

References

da Silva, A. R. et al. (2018) Modeling the Three Phases of the Soaking Kinetics of Seeds. Agronomy Journal, 110:164-170. doi:10.2134/agronj2017.07.0373