Learn R Programming

seedwater (version 2.0)

waterloss: Seed Water Loss Data

Description

Hypothetical data from an experiment containing observations of water content (g/g) of seeds in a drying process for 2 hours.

Usage

data("onionseeds")

Arguments

Format

A data frame with 11 observations on the following 2 variables:

Time

a numeric vector containing values of drying time, in hours.

WaterContent

a numeric vector containing values of water content (g/g) of a seed sample.

Examples

Run this code
# NOT RUN {
data(waterloss)
str(waterloss)
summary(waterloss)
plot(WaterContent ~ Time, data = waterloss)
# }

Run the code above in your browser using DataLab