powered by
Data from a lab experiment containing observations of onion seed sample weight (g) subjected to a soaking process for 96 hours.
data("onionseeds")
A data frame with 23 observations on the following 2 variables:
Time
a numeric vector containing values of soaking time, in hours.
Weight
a numeric vector containing values of weight (g) of a onion seed sample.
# NOT RUN { data(onionseeds) str(onionseeds) summary(onionseeds) plot(Weight ~ Time, data = onionseeds) # }
Run the code above in your browser using DataLab