powered by
Hypothetical data from an experiment containing observations of water content (g/g) of seeds in a drying process for 2 hours.
data("onionseeds")
A data frame with 11 observations on the following 2 variables:
Time
a numeric vector containing values of drying time, in hours.
WaterContent
a numeric vector containing values of water content (g/g) of a seed sample.
# NOT RUN { data(waterloss) str(waterloss) summary(waterloss) plot(WaterContent ~ Time, data = waterloss) # }
Run the code above in your browser using DataLab